import {
    Injectable
} from 'angular2/core'

import {ValidationRule} from './ValidationRule';
import {ValidationError} from './ValidationError';
import {ValidationErrorTypeEnum} from './ValidationErrorTypeEnum';

const xregexp = require('xregexp');

@Injectable()
export class ValidationService {

    public test(value:string, rules:ValidationRule[]):ValidationError[] {
        const errors:ValidationError[] = [];

        rules.forEach((rule:ValidationRule)=> {
            if (!rule.allowBlank() && value === "") {
                errors.push(
                    new ValidationError(
                        ValidationErrorTypeEnum.VALUE_IS_EMPTY,
                        rule,
                        value
                    )
                );
            }

            if (!xregexp(rule.getPattern()).test(value)) {
                errors.push(
                    new ValidationError(
                        ValidationErrorTypeEnum.VALUE_DOES_NOT_SATISFY_REGULAR_EXPRESSION,
                        rule,
                        value
                    )
                );
            }
        });
        return errors;
    }
}
